@@ -1,10 +1,7 @@
 from cli_ui import fatal
-
 from gitlabform.constants import EXIT_INVALID_INPUT
-from gitlabform.lists import OmissionReason, Groups
-
-
 from gitlabform.gitlab.core import NotFoundException
+from gitlabform.lists import OmissionReason, Groups
 
 
 class GroupsProvider:
@@ -14,9 +11,10 @@ class GroupsProvider:
     and the fact that the group and project names case are somewhat case-sensitive.
     """
 
-    def __init__(self, gitlab, configuration):
+    def __init__(self, gitlab, configuration, recurse_subgroups):
         self.gitlab = gitlab
         self.configuration = configuration
+        self.recurse_subgroups = recurse_subgroups
 
     def get_groups(self, target: str) -> Groups:
         """
@@ -25,19 +23,29 @@ class GroupsProvider:
         """
 
         if target not in ["ALL", "ALL_DEFINED"]:
-            groups = self._get_single_group(target)
+            groups = self._get_single_group(target, self.recurse_subgroups)
         else:
             groups = self._get_groups(target)
 
         return groups
 
-    def _get_single_group(self, target: str) -> Groups:
+    def _get_single_group(self, target: str, recurse_subgroups: bool) -> Groups:
         groups = Groups()
 
         # it may be a subgroup or a group...
         try:
             maybe_group = self.gitlab.get_group_case_insensitive(target)
-            groups.add_requested([maybe_group["full_path"]])
+            path = maybe_group["full_path"]
+            groups.add_requested([path])
+
+            if recurse_subgroups:
+                descendants = self.gitlab.get_group_descendants(path)
+                groups.add_requested([group["full_path"] for group in descendants])
+
+                groups.add_omitted(
+                    OmissionReason.SKIPPED,
+                    self._get_skipped_groups(groups.get_effective()),
+                )
 
         except NotFoundException:
             # ...or a single project, which we ignore here
