@@ -23,26 +23,20 @@ class AbstractProcessors(ABC):
         entity_reference: str,
         configuration: dict,
         dry_run: bool,
+        diff_only_changed: bool,
         effective_configuration: EffectiveConfigurationFile,
         only_sections: List[str],
     ):
         for processor in self.processors:
             if only_sections == "all" or processor.configuration_name in only_sections:
-                try:
-                    processor.process(
-                        entity_reference,
-                        configuration,
-                        dry_run,
-                        effective_configuration,
-                    )
-                except requests.exceptions.ConnectionError as e:
-                    if (
-                        "RemoteDisconnected('Remote end closed connection without response')"
-                        in str(e)
-                    ):
-                        print("thats the case")
-
-        else:
-            verbose(
-                f"Skipping section '{processor.configuration_name}' - not in --only-sections list."
-            )
+                processor.process(
+                    entity_reference,
+                    configuration,
+                    dry_run,
+                    diff_only_changed,
+                    effective_configuration,
+                )
+            else:
+                verbose(
+                    f"Skipping section '{processor.configuration_name}' - not in --only-sections list."
+                )
