@@ -5,7 +5,8 @@ from typing import Callable, Union
 import requests
 from cli_ui import debug as verbose
 
-from gitlabform.gitlab import GitLab
+from gitlabform.gitlab import GitLab, PythonGitlab
+from gitlabform.gitlab import GitlabWrapper
 from gitlabform.output import EffectiveConfigurationFile
 from gitlabform.processors.util.decorators import configuration_to_safe_dict
 
@@ -20,6 +21,7 @@ class AbstractProcessor(ABC):
                 [str, list[dict[str, Union[str, int]]], list[dict[str, int]]], bool
             ],
         ] = {}
+        self.gl: PythonGitlab = GitlabWrapper(self.gitlab).get_gitlab()
 
     @configuration_to_safe_dict
     def process(
@@ -27,6 +29,7 @@ class AbstractProcessor(ABC):
         project_or_project_and_group: str,
         configuration,
         dry_run: bool,
+        diff_only_changed: bool,
         effective_configuration: EffectiveConfigurationFile,
     ):
         if self._section_is_in_config(configuration):
@@ -48,9 +51,20 @@ class AbstractProcessor(ABC):
                 verbose(
                     f"Processing section '{self.configuration_name}' in dry-run mode."
                 )
+                project_transfer_source = ""
+                try:
+                    project_transfer_source = configuration["project"]["transfer_from"]
+                    verbose(
+                        f"""Project {project_or_project_and_group} is configured to be transferred, 
+                        diffing config from transfer source project {project_transfer_source}."""
+                    )
+                except KeyError:
+                    pass
+
                 self._print_diff(
-                    project_or_project_and_group,
+                    project_transfer_source or project_or_project_and_group,
                     configuration.get(self.configuration_name),
+                    diff_only_changed=diff_only_changed,
                 )
             else:
                 verbose(f"Processing section '{self.configuration_name}'")
@@ -130,7 +144,9 @@ class AbstractProcessor(ABC):
     ):
         pass
 
-    def _print_diff(self, project_or_project_and_group: str, entity_config):
+    def _print_diff(
+        self, project_or_project_and_group: str, entity_config, diff_only_changed: bool
+    ):
         verbose(f"Diffing for section '{self.configuration_name}' is not supported yet")
 
     def _needs_update(
