@@ -14,6 +14,9 @@ from gitlabform.processors.project.deploy_keys_processor import (
 from gitlabform.processors.project.files_processor import FilesProcessor
 from gitlabform.processors.project.hooks_processor import HooksProcessor
 from gitlabform.processors.project.members_processor import MembersProcessor
+from gitlabform.processors.project.job_token_scope_processor import (
+    JobTokenScopeProcessor,
+)
 from gitlabform.processors.project.project_processor import ProjectProcessor
 from gitlabform.processors.project.project_push_rules_processor import (
     ProjectPushRulesProcessor,
@@ -21,6 +24,9 @@ from gitlabform.processors.project.project_push_rules_processor import (
 from gitlabform.processors.project.project_settings_processor import (
     ProjectSettingsProcessor,
 )
+from gitlabform.processors.project.project_labels_processor import (
+    ProjectLabelsProcessor,
+)
 from gitlabform.processors.shared.protected_environments_processor import (
     ProtectedEnvironmentsProcessor,
 )
@@ -52,6 +58,8 @@ class ProjectProcessors(AbstractProcessors):
             ProjectProcessor(gitlab),
             ProjectSettingsProcessor(gitlab),
             ProjectPushRulesProcessor(gitlab),
+            ProjectLabelsProcessor(gitlab),
+            JobTokenScopeProcessor(gitlab),
             DeployKeysProcessor(gitlab),
             VariablesProcessor(gitlab),
             BranchesProcessor(gitlab, strict),
