@@ -19,6 +19,7 @@ from tests.acceptance import (
     get_random_name,
     create_users,
     get_random_password,
+    randomize_case,
 )
 
 from cli_ui.tests import MessageRecorder
@@ -293,12 +294,63 @@ def make_user(
         return user
 
     yield _make_user
-
     for user in created_users:
         with allowed_codes(404):
             gl.users.delete(user.id)
 
 
+@pytest.fixture(scope="function")
+def make_project_member_developer(gl, project_for_function):
+    username = get_random_name("user")
+
+    user = _create_user_and_add_to_project(gl, project_for_function, username)
+
+    yield user
+
+    gl.users.delete(user.id)
+
+
+@pytest.fixture(scope="function")
+def make_project_member_developer_random_case(gl, project_for_function):
+    username = randomize_case(get_random_name("user"))
+
+    user = _create_user_and_add_to_project(gl, project_for_function, username)
+
+    yield user
+
+    gl.users.delete(user.id)
+
+
+@pytest.fixture(scope="function")
+def make_multiple_project_members_for_pagination(gl, project_for_function):
+    users = create_users(randomize_case(get_random_name("user")), 25)
+
+    for user in users:
+        project_for_function.members.create(
+            {"user_id": user.id, "access_level": AccessLevel.DEVELOPER.value}
+        )
+
+    yield users
+
+    for user in users:
+        user.delete()
+
+
+def _create_user_and_add_to_project(gl, project, username):
+    user = gl.users.create(
+        {
+            "username": username,
+            "email": username + "@example.com",
+            "name": username + " Example",
+            "password": get_random_password(),
+        }
+    )
+    project.members.create(
+        {"user_id": user.id, "access_level": AccessLevel.DEVELOPER.value}
+    )
+    return user
+
+
 @pytest.fixture(scope="class")
 def make_project_access_token(
     project,
