@@ -5,7 +5,7 @@ from tests.acceptance import (
 
 class TestDeployKeysAllProjects:
     def test__deploy_key_to_all_projects(
-        self, gitlab, group, project, other_project, public_ssh_key
+        self, group, project, other_project, public_ssh_key
     ):
         deploy_key_to_all_projects = f"""
         projects_and_groups:
@@ -16,16 +16,13 @@ class TestDeployKeysAllProjects:
                 title: common_key
                 can_push: false
         """
-        run_gitlabform(deploy_key_to_all_projects, group)
+        run_gitlabform(deploy_key_to_all_projects, group.full_path)
 
-        deploy_keys1 = gitlab.get_deploy_keys(f"{group}/{project}")
-        assert len(deploy_keys1) == 1
-
-        deploy_keys2 = gitlab.get_deploy_keys(f"{group}/{other_project}")
-        assert len(deploy_keys2) == 1
+        assert len(project.keys.list()) == 1
+        assert len(other_project.keys.list()) == 1
 
     def test__deploy_key_with_spaces_in_comment_to_all_projects(
-        self, gitlab, group, project, other_project, public_ssh_key
+        self, group, project, other_project, public_ssh_key
     ):
         public_ssh_key = f"{public_ssh_key} this is a comment with spaces"
 
@@ -40,8 +37,5 @@ class TestDeployKeysAllProjects:
         """
         run_gitlabform(deploy_key_to_all_projects, group)
 
-        deploy_keys1 = gitlab.get_deploy_keys(f"{group}/{project}")
-        assert len(deploy_keys1) == 1
-
-        deploy_keys2 = gitlab.get_deploy_keys(f"{group}/{other_project}")
-        assert len(deploy_keys2) == 1
+        assert len(project.keys.list()) == 1
+        assert len(other_project.keys.list()) == 1
