@@ -2,10 +2,10 @@ from tests.acceptance import run_gitlabform
 
 
 class TestGroupVariables:
-    def test__single_variable(self, gitlab, group_for_function):
+    def test__single_variable(self, group_for_function):
         config_single_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -14,13 +14,13 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
+        variables = group_for_function.variables.list()
         assert len(variables) == 1
 
-    def test__delete_variable(self, gitlab, group_for_function):
+    def test__delete_variable(self, group_for_function):
         config_single_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -29,13 +29,13 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
+        variables = group_for_function.variables.list()
         assert len(variables) == 1
-        assert variables[0]["value"] == "123"
+        assert variables[0].value == "123"
 
         config_delete_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -45,13 +45,13 @@ class TestGroupVariables:
 
         run_gitlabform(config_delete_variable, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
+        variables = group_for_function.variables.list()
         assert len(variables) == 0
 
-    def test__reset_single_variable(self, gitlab, group_for_function):
+    def test__reset_single_variable(self, group_for_function):
         config_single_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -60,13 +60,13 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
+        variables = group_for_function.variables.list()
         assert len(variables) == 1
-        assert variables[0]["value"] == "123"
+        assert variables[0].value == "123"
 
         config_single_variable2 = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -75,14 +75,14 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable2, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
+        variables = group_for_function.variables.list()
         assert len(variables) == 1
-        assert variables[0]["value"] == "123456"
+        assert variables[0].value == "123456"
 
-    def test__more_variables(self, gitlab, group_for_function):
+    def test__more_variables(self, group_for_function):
         config_more_variables = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -94,15 +94,15 @@ class TestGroupVariables:
 
         run_gitlabform(config_more_variables, group_for_function)
 
-        variables = gitlab.get_group_variables(group_for_function)
-        variables_keys = {variable["key"] for variable in variables}
+        variables = group_for_function.variables.list()
+        variables_keys = {variable.key for variable in variables}
         assert len(variables) == 2
         assert variables_keys == {"FOO", "BAR"}
 
-    def test__masked_variables(self, gitlab, group_for_function):
+    def test__masked_variables(self, group_for_function):
         masked_variables = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -113,14 +113,14 @@ class TestGroupVariables:
 
         run_gitlabform(masked_variables, group_for_function)
 
-        variable = gitlab.get_group_variable_object(group_for_function, "FOO")
-        assert variable["value"] == "12345678"
-        assert variable["masked"]
+        variable = group_for_function.variables.get("FOO")
+        assert variable.value == "12345678"
+        assert variable.masked
 
-    def test__protected_variables(self, gitlab, group_for_function):
+    def test__protected_variables(self, group_for_function):
         protected_variables = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -130,14 +130,14 @@ class TestGroupVariables:
 
         run_gitlabform(protected_variables, group_for_function)
 
-        variable = gitlab.get_group_variable_object(group_for_function, "FOO")
-        assert variable["value"] == "123"
-        assert variable["protected"]
+        variable = group_for_function.variables.get("FOO")
+        assert variable.value == "123"
+        assert variable.protected
 
-    def test__protected_change_variables(self, gitlab, group_for_function):
+    def test__protected_change_variables(self, group_for_function):
         config_single_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -146,13 +146,13 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable, group_for_function)
 
-        variable = gitlab.get_group_variable_object(group_for_function, "FOO")
-        assert variable["value"] == "123"
-        assert variable["protected"] is False
+        variable = group_for_function.variables.get("FOO")
+        assert variable.value == "123"
+        assert variable.protected is False
 
         protected_variables = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: FOO
@@ -162,14 +162,14 @@ class TestGroupVariables:
 
         run_gitlabform(protected_variables, group_for_function)
 
-        variable = gitlab.get_group_variable_object(group_for_function, "FOO")
-        assert variable["value"] == "123"
-        assert variable["protected"] is True
+        variable = group_for_function.variables.get("FOO")
+        assert variable.value == "123"
+        assert variable.protected is True
 
-    def test__not_masked_and_not_protected_variable(self, gitlab, group_for_function):
+    def test__not_masked_and_not_protected_variable(self, group_for_function):
         config_single_variable = f"""
         projects_and_groups:
-          {group_for_function}/*:
+          {group_for_function.full_path}/*:
             group_variables:
               foo:
                 key: DOUBLE_NOT
@@ -180,6 +180,6 @@ class TestGroupVariables:
 
         run_gitlabform(config_single_variable, group_for_function)
 
-        variable = gitlab.get_group_variable_object(group_for_function, "DOUBLE_NOT")
-        assert variable["masked"] is False
-        assert variable["protected"] is False
+        variable = group_for_function.variables.get("DOUBLE_NOT")
+        assert variable.masked is False
+        assert variable.protected is False
